@@ -26,7 +26,7 @@ my %Top_tag_order;
 
 BEGIN
 {
-  $VERSION = "1.12";
+  $VERSION = "1.13";
 
   $Tags =
   {
@@ -185,41 +185,57 @@ BEGIN
   }
 }
 
+sub DESTROY {}
+
 sub AUTOLOAD
 {
   my ($self) = @_;                         # don't change @_ because of the goto
-  return if $AUTOLOAD =~ /::DESTROY$/;
   my $func = $AUTOLOAD;
   # print "autoloading $func\n";
   $func =~ s/^.*:://;
   my $tag;
   carp "Undefined subroutine $func called"
-    if $func !~ /^add_(.*)$/ ||
-       !($tag = $Funcs{lc $1}) ||
+    if $func !~ /^(add|get)_(.*)$/ ||
+       !($tag = $Funcs{lc $2}) ||
        !exists $Top_tag_order{$tag};
   no strict "refs";
-  *$func = sub
+  if ($1 eq "add")
   {
-    my $self = shift;
-    my $r = $self->add_record(tag => $tag);
-    unless ($tag =~ /^(HEAD|TRLR)$/)
+    *$func = sub
     {
-      my $x = @_ ? shift : $tag eq "SUBM" ? "SUBM" : substr $tag, 0, 1;
-      carp "Invalid xref $x requested in $func"
-        unless $x =~ /^[[:alpha:]]+(\d*)$/;
-      $x = $self->next_xref($x) unless length $1;
-      $r->{xref} = $x;
-      $self->{xrefs}{$r->{xref}} = $r;
-    }
-    $r
-  };
+      my $self = shift;
+      my $r = $self->add_record(tag => $tag);
+      unless ($tag =~ /^(HEAD|TRLR)$/)
+      {
+        my $x = @_ ? shift : $tag eq "SUBM" ? "SUBM" : substr $tag, 0, 1;
+        carp "Invalid xref $x requested in $func"
+          unless $x =~ /^[^\W\d_]+(\d*)$/;
+        $x = $self->next_xref($x) unless length $1;
+        $r->{xref} = $x;
+        $self->{xrefs}{$r->{xref}} = $r;
+      }
+      $r
+    };
+  }
+  else
+  {
+    *$func = sub
+    {
+      my $self   = shift;
+      my ($xref) = @_;
+      my $nxr    = !defined $xref;
+      my @a      = grep { $_->{tag} eq $tag && ($nxr || $_->{xref} eq $xref) }
+                        @{$self->{record}->_items};
+      wantarray ? @a : $a[0]
+    };
+  }
   goto &$func
 }
 
-use Gedcom::Grammar    1.12;
-use Gedcom::Individual 1.12;
-use Gedcom::Family     1.12;
-use Gedcom::Event      1.12;
+use Gedcom::Grammar    1.13;
+use Gedcom::Individual 1.13;
+use Gedcom::Family     1.13;
+use Gedcom::Event      1.13;
 
 sub new
 {
@@ -323,7 +339,7 @@ sub new
       for (split /\n/, <<'EOH')
 This output was generated by Gedcom.pm.
 Gedcom.pm is Copyright 1999-2003, Paul Johnson (pjcj@cpan.org)
-Version 1.12 - 2nd February 2003
+Version 1.13 - 6th December 2003
 
 Gedcom.pm is free.  It is licensed under the same terms as Perl itself.
 
@@ -377,7 +393,7 @@ sub write_xml
 
 This output was generated by Gedcom.pm.
 Gedcom.pm is Copyright 1999-2003, Paul Johnson (pjcj@cpan.org)
-Version 1.12 - 2nd February 2003
+Version 1.13 - 6th December 2003
 
 Gedcom.pm is free.  It is licensed under the same terms as Perl itself.
 
@@ -636,7 +652,7 @@ __END__
 
 Gedcom - a module to manipulate Gedcom genealogy files
 
-Version 1.12 - 2nd February 2003
+Version 1.13 - 6th December 2003
 
 =head1 SYNOPSIS
 
@@ -664,8 +680,15 @@ Version 1.12 - 2nd February 2003
   my @families = $ged->families;
   my $me = $ged->get_individual("Paul Johnson");
   my $xref = $ged->next_xref("I");
-
   my $record = $ged->add_header;
+                     add_submitter
+                     add_individual
+                     add_family
+                     add_note
+                     add_repository
+                     add_source
+                     add_trailer
+  my $source = $ged->get_source("S1");
 
 =head1 DESCRIPTION
 
@@ -1115,4 +1138,30 @@ The matches are:
 
 Return the next available xref with the specified prefix.
 
+=head2 add_record
+
+       add_header
+       add_submitter
+       add_individual
+       add_family
+       add_note
+       add_repository
+       add_source
+       add_trailer
+
+Create and return a new record of the specified type.
+
+=head2 get_record
+
+       get_header
+       get_submitter
+       get_family
+       get_note
+       get_repository
+       get_source
+       get_trailer
+
+Return all records of the specified type.  In scalar context just return the
+first record.  If a parameter is passed in, just return records of that xref.
+
 =cut
